@@ -1,4 +1,4 @@
-/* 
+/*
  * e-cell-pixbuf.h - An ECell that displays a GdkPixbuf
  * Copyright 2001, Ximian, Inc.
  *
@@ -36,10 +36,6 @@ typedef struct _ECellPixbufClass ECellPixbufClass;
 
 struct _ECellPixbuf {
     ECell parent;
-
-	int selected_column;
-	int focused_column;
-	int unselected_column;
 };
 
 struct _ECellPixbufClass {
