@@ -1,12 +1,26 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * e-table-selection-model.c: a Table Selection Model
+ * e-table-selection-model.c
+ * Copyright 2000, 2001, Ximian, Inc.
  *
- * Author:
- *   Christopher James Lahey <clahey@ximian.com>
+ * Authors:
+ *   Chris Lahey <clahey@ximian.com>
  *
- * (C) 2000, 2001 Ximian, Inc.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public
+ * License, version 2, as published by the Free Software Foundation.
+ *
+ * This library is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU Library General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
+ * 02111-1307, USA.
  */
+
 #include <config.h>
 #include "e-table-selection-model.h"
 
@@ -222,9 +236,10 @@ etsm_destroy (GtkObject *object)
 
 	etsm = E_TABLE_SELECTION_MODEL (object);
 
-	if (etsm->model_changed_idle_id) {
-		g_source_remove(etsm->model_changed_idle_id);
-	}
+	if (etsm->model_changed_idle_id)
+		g_source_remove (etsm->model_changed_idle_id);
+	etsm->model_changed_idle_id = 0;
+
 	drop_model(etsm);
 	free_hash(etsm);
 
