@@ -1,13 +1,38 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+/* 
+ * e-table-sorter.h
+ * Copyright 2000, 2001, Ximian, Inc.
+ *
+ * Authors:
+ *   Chris Lahey <clahey@ximian.com>
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public
+ * License, version 2, as published by the Free Software Foundation.
+ *
+ * This library is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU Library General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
+ * 02111-1307, USA.
+ */
+
 #ifndef _E_TABLE_SORTER_H_
 #define _E_TABLE_SORTER_H_
 
 #include <gtk/gtkobject.h>
+#include <gal/util/e-sorter.h>
 #include <gal/e-table/e-table-model.h>
 #include <gal/e-table/e-table-subset-variable.h>
 #include <gal/e-table/e-table-sort-info.h>
 #include <gal/e-table/e-table-header.h>
 
+G_BEGIN_DECLS
+
 #define E_TABLE_SORTER_TYPE        (e_table_sorter_get_type ())
 #define E_TABLE_SORTER(o)          (GTK_CHECK_CAST ((o), E_TABLE_SORTER_TYPE, ETableSorter))
 #define E_TABLE_SORTER_CLASS(k)    (GTK_CHECK_CLASS_CAST((k), E_TABLE_SORTER_TYPE, ETableSorterClass))
@@ -15,7 +40,7 @@
 #define E_IS_TABLE_SORTER_CLASS(k) (GTK_CHECK_CLASS_TYPE ((k), E_TABLE_SORTER_TYPE))
 
 typedef struct {
-	GtkObject base;
+	ESorter base;
 
 	ETableModel    *source;
 	ETableHeader   *full_header;
@@ -34,15 +59,13 @@ typedef struct {
 } ETableSorter;
 
 typedef struct {
-	GtkObjectClass parent_class;
+	ESorterClass parent_class;
 } ETableSorterClass;
 
-GtkType       e_table_sorter_get_type (void);
-ETableSorter *e_table_sorter_new      (ETableModel *etm, ETableHeader *full_header, ETableSortInfo *sort_info);
-
-gint          e_table_sorter_model_to_sorted (ETableSorter *sorter, int row);
-gint          e_table_sorter_sorted_to_model (ETableSorter *sorter, int row);
-
-gboolean      e_table_sorter_needs_sorting   (ETableSorter *sorter);
+GtkType       e_table_sorter_get_type                   (void);
+ETableSorter *e_table_sorter_new                        (ETableModel     *etm,
+							 ETableHeader    *full_header,
+							 ETableSortInfo  *sort_info);
+G_END_DECLS
 
 #endif /* _E_TABLE_SORTER_H_ */
