@@ -1,5 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/* 
+/*
  * e-tree.c
  * Copyright 2000, 2001, Ximian, Inc.
  *
@@ -28,12 +28,11 @@
 #include <stdio.h>
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtksignal.h>
-#include <libgnomeui/gnome-canvas-rect-ellipse.h>
+#include <libgnomecanvas/gnome-canvas-rect-ellipse.h>
 
 #include "gal/util/e-i18n.h"
 #include <gal/util/e-util.h>
 #include <gal/widgets/e-canvas.h>
-#include <gal/widgets/e-canvas-background.h>
 
 #include <gal/e-table/e-table-column-specification.h>
 #include <gal/e-table/e-table-header-item.h>
@@ -76,8 +75,6 @@ enum {
 	CLICK,
 	KEY_PRESS,
 	START_DRAG,
-	STATE_CHANGE,
-	WHITE_SPACE_EVENT,
 
 	TREE_DRAG_BEGIN,
 	TREE_DRAG_END,
@@ -100,7 +97,6 @@ enum {
 	ARG_DRAW_FOCUS,
 	ARG_ETTA,
 	ARG_UNIFORM_ROW_HEIGHT,
-	ARG_ALWAYS_SEARCH
 };
 
 enum {
@@ -117,23 +113,12 @@ struct ETreePriv {
 
 	ETableHeader *full_header, *header;
 
-	guint structure_change_id, expansion_change_id;
-
 	ETableSortInfo *sort_info;
 	ESorter   *sorter;
 
-	guint sort_info_change_id, group_info_change_id;
-
 	ESelectionModel *selection;
 	ETableSpecification *spec;
 
-	ETableSearch     *search;
-
-	ETableCol        *current_search_col;
-
-	guint   	  search_search_id;
-	guint   	  search_accept_id;
-
 	int reflow_idle_id;
 	int scroll_idle_id;
 	int hover_idle_id;
@@ -170,9 +155,6 @@ struct ETreePriv {
 
 	guint uniform_row_height : 1;
 
-	guint search_col_set : 1;
-	guint always_search : 1;
-
 	ECursorMode cursor_mode;
 
 	int drop_row;
@@ -196,7 +178,7 @@ struct ETreePriv {
 	GList *expanded_list;
 };
 
-static guint et_signals [LAST_SIGNAL] = { 0, };
+static gint et_signals [LAST_SIGNAL] = { 0, };
 
 static void et_grab_focus (GtkWidget *widget);
 
@@ -241,7 +223,6 @@ static void et_drag_data_received(GtkWidget *widget,
 				  guint time,
 				  ETree *et);
 
-static gint et_focus (GtkContainer *container, GtkDirectionType direction);
 
 static void scroll_off (ETree *et);
 static void scroll_on (ETree *et, guint scroll_direction);
@@ -274,252 +255,51 @@ et_disconnect_from_etta (ETree *et)
 	et->priv->table_rows_deleted_id = 0;
 }
 
-static void
-clear_current_search_col (ETree *et)
-{
-	et->priv->search_col_set = FALSE;
-}
-
-static ETableCol *
-current_search_col (ETree *et)
-{
-	if (!et->priv->search_col_set) {
-		et->priv->current_search_col = 
-			e_table_util_calculate_current_search_col (et->priv->header,
-								   et->priv->full_header,
-								   et->priv->sort_info,
-								   et->priv->always_search);
-		et->priv->search_col_set = TRUE;
-	}
-
-	return et->priv->current_search_col;
-}
-
-static void
-e_tree_state_change (ETree *et)
-{
-	gtk_signal_emit (GTK_OBJECT (et),
-			 et_signals [STATE_CHANGE]);
-}
-
-static void
-change_trigger (GtkObject *object, ETree *et)
-{
-	e_tree_state_change (et);
-}
-
-static void
-search_col_change_trigger (GtkObject *object, ETree *et)
-{
-	clear_current_search_col (et);
-	e_tree_state_change (et);
-}
-
-static void
-disconnect_header (ETree *e_tree)
-{
-	if (e_tree->priv->header == NULL)
-		return;
-
-	if (e_tree->priv->structure_change_id)
-		gtk_signal_disconnect (GTK_OBJECT (e_tree->priv->header),
-				       e_tree->priv->structure_change_id);
-	if (e_tree->priv->expansion_change_id)
-		gtk_signal_disconnect (GTK_OBJECT (e_tree->priv->header),
-				       e_tree->priv->expansion_change_id);
-	if (e_tree->priv->sort_info) {
-		if (e_tree->priv->sort_info_change_id)
-			gtk_signal_disconnect (GTK_OBJECT (e_tree->priv->sort_info),
-					       e_tree->priv->sort_info_change_id);
-		if (e_tree->priv->group_info_change_id)
-			gtk_signal_disconnect (GTK_OBJECT (e_tree->priv->sort_info),
-					       e_tree->priv->group_info_change_id);
-
-		gtk_object_unref(GTK_OBJECT(e_tree->priv->sort_info));
-	}
-	gtk_object_unref(GTK_OBJECT(e_tree->priv->header));
-	e_tree->priv->header = NULL;
-	e_tree->priv->sort_info = NULL;
-}
-
-static void
-connect_header (ETree *e_tree, ETableState *state)
-{
-	if (e_tree->priv->header != NULL)
-		disconnect_header (e_tree);
-
-	e_tree->priv->header = e_table_state_to_header (GTK_WIDGET(e_tree), e_tree->priv->full_header, state);
-
-	e_tree->priv->structure_change_id =
-		gtk_signal_connect (GTK_OBJECT (e_tree->priv->header), "structure_change",
-				    search_col_change_trigger, e_tree);
-	e_tree->priv->expansion_change_id =
-		gtk_signal_connect (GTK_OBJECT (e_tree->priv->header), "expansion_change",
-				    change_trigger, e_tree);
-
-	if (state->sort_info) {
-		e_tree->priv->sort_info = e_table_sort_info_duplicate(state->sort_info);
-		e_table_sort_info_set_can_group (e_tree->priv->sort_info, FALSE);
-		e_tree->priv->sort_info_change_id =
-			gtk_signal_connect (GTK_OBJECT (e_tree->priv->sort_info), "sort_info_changed",
-					    search_col_change_trigger, e_tree);
-		e_tree->priv->group_info_change_id =
-			gtk_signal_connect (GTK_OBJECT (e_tree->priv->sort_info), "group_info_changed",
-					    search_col_change_trigger, e_tree);
-	} else
-		e_tree->priv->sort_info = NULL;
-
-	gtk_object_set(GTK_OBJECT(e_tree->priv->header),
-		       "sort_info", e_tree->priv->sort_info,
-		       NULL);
-}
-
 static void
 et_destroy (GtkObject *object)
 {
 	ETree *et = E_TREE (object);
 
-	if (et->priv->search) {
-		if (et->priv->search_search_id)
-			gtk_signal_disconnect (GTK_OBJECT (et->priv->search),
-					       et->priv->search_search_id);
-		if (et->priv->search_accept_id)
-			gtk_signal_disconnect (GTK_OBJECT (et->priv->search),
-					       et->priv->search_accept_id);
-		gtk_object_unref (GTK_OBJECT (et->priv->search));
+	if (et->priv) {
+
+		if (et->priv->reflow_idle_id)
+			g_source_remove(et->priv->reflow_idle_id);
+		et->priv->reflow_idle_id = 0;
+
+		scroll_off (et);
+		hover_off (et);
+		e_free_string_list (et->priv->expanded_list);
+
+		et_disconnect_from_etta (et);
+
+		gtk_object_unref (GTK_OBJECT (et->priv->etta));
+		gtk_object_unref (GTK_OBJECT (et->priv->model));
+		gtk_object_unref (GTK_OBJECT (et->priv->sorted));
+		gtk_object_unref (GTK_OBJECT (et->priv->full_header));
+		gtk_object_unref (GTK_OBJECT (et->priv->header));
+		gtk_object_unref (GTK_OBJECT (et->priv->sort_info));
+		gtk_object_unref (GTK_OBJECT (et->priv->selection));
+		if (et->priv->spec)
+			gtk_object_unref (GTK_OBJECT (et->priv->spec));
+
+		if (et->priv->sorter)
+			gtk_object_unref (GTK_OBJECT (et->priv->sorter));
+
+		if (et->priv->header_canvas)
+			gtk_widget_destroy (GTK_WIDGET (et->priv->header_canvas));
+
+		if (et->priv->site)
+			e_tree_drag_source_unset (et);
+
+		gtk_widget_destroy (GTK_WIDGET (et->priv->table_canvas));
+
+		g_free(et->priv);
+		et->priv = NULL;
 	}
 
-	if (et->priv->reflow_idle_id)
-		g_source_remove(et->priv->reflow_idle_id);
-	et->priv->reflow_idle_id = 0;
-
-	scroll_off (et);
-	hover_off (et);
-	e_free_string_list (et->priv->expanded_list);
-
-	et_disconnect_from_etta (et);
-
-	gtk_object_unref (GTK_OBJECT (et->priv->etta));
-	gtk_object_unref (GTK_OBJECT (et->priv->model));
-	gtk_object_unref (GTK_OBJECT (et->priv->sorted));
-	gtk_object_unref (GTK_OBJECT (et->priv->full_header));
-	disconnect_header (et);
-	gtk_object_unref (GTK_OBJECT (et->priv->selection));
-	if (et->priv->spec)
-		gtk_object_unref (GTK_OBJECT (et->priv->spec));
-
-	if (et->priv->sorter)
-		gtk_object_unref (GTK_OBJECT (et->priv->sorter));
-
-	if (et->priv->header_canvas)
-		gtk_widget_destroy (GTK_WIDGET (et->priv->header_canvas));
-
-	if (et->priv->site)
-		e_tree_drag_source_unset (et);
-
-	gtk_widget_destroy (GTK_WIDGET (et->priv->table_canvas));
-
-	g_free(et->priv);
-	et->priv = NULL;
-
 	(*parent_class->destroy)(object);
 }
 
-static void
-et_unrealize (GtkWidget *widget)
-{
-	scroll_off (E_TREE (widget));
-	hover_off (E_TREE (widget));
-
-	if (GTK_WIDGET_CLASS (parent_class)->unrealize)
-		GTK_WIDGET_CLASS (parent_class)->unrealize (widget);
-}
-
-typedef struct {
-	ETree *et;
-	char *string;
-} SearchSearchStruct;
-
-static gboolean
-search_search_callback (ETreeModel *model, ETreePath path, gpointer data)
-{
-	SearchSearchStruct *cb_data = data;
-	const void *value;
-	ETableCol *col = current_search_col (cb_data->et);
-
-	value = e_tree_model_value_at (model, path, col->col_idx);
-
-	return col->search (value, cb_data->string);
-}
-
-static gboolean
-et_search_search (ETableSearch *search, char *string, ETableSearchFlags flags, ETree *et)
-{
-	ETreePath cursor;
-	ETreePath found;
-	SearchSearchStruct cb_data;
-	ETableCol *col = current_search_col (et);
-
-	if (col == NULL)
-		return FALSE;
-
-	cb_data.et = et;
-	cb_data.string = string;
-
-	cursor = e_tree_get_cursor (et);
-	cursor = e_tree_sorted_model_to_view_path (et->priv->sorted, cursor);
-
-	g_return_val_if_fail (cursor != NULL, FALSE);
-
-	if (flags & E_TABLE_SEARCH_FLAGS_CHECK_CURSOR_FIRST) {
-		const void *value;
-
-		value = e_tree_model_value_at (E_TREE_MODEL (et->priv->sorted), cursor, col->col_idx);
-
-		if (col->search (value, string)) {
-			return TRUE;
-		}
-	}
-
-	found = e_tree_model_node_find (E_TREE_MODEL (et->priv->sorted), cursor, NULL, E_TREE_FIND_NEXT_FORWARD, search_search_callback, &cb_data);
-	if (found == NULL)
-		found = e_tree_model_node_find (E_TREE_MODEL (et->priv->sorted), NULL, cursor, E_TREE_FIND_NEXT_FORWARD, search_search_callback, &cb_data);
-
-	if (found && found != cursor) {
-		int model_row;
-
-		e_tree_table_adapter_show_node (et->priv->etta, found);
-		model_row = e_tree_table_adapter_row_of_node (et->priv->etta, found);
-
-		cursor = e_tree_sorted_view_to_model_path (et->priv->sorted, found);
-
-		e_selection_model_select_as_key_press(E_SELECTION_MODEL (et->priv->selection), model_row, col->col_idx, GDK_CONTROL_MASK);
-		return TRUE;
-	} else if (!(flags & E_TABLE_SEARCH_FLAGS_CHECK_CURSOR_FIRST)) {
-		const void *value;
-
-		value = e_tree_model_value_at (E_TREE_MODEL (et->priv->sorted), cursor, col->col_idx);
-
-		return col->search (value, string);
-	} else
-		return FALSE;
-}
-
-static void
-et_search_accept (ETableSearch *search, ETree *et)
-{
-	ETableCol *col = current_search_col (et);
-	int cursor;
-
-	if (col == NULL)
-		return;
-
-	gtk_object_get(GTK_OBJECT(et->priv->selection),
-		       "cursor_row", &cursor,
-		       NULL);
-	e_selection_model_select_as_key_press(E_SELECTION_MODEL (et->priv->selection), cursor, col->col_idx, 0);
-}
-
 static void
 e_tree_init (GtkObject *object)
 {
@@ -528,89 +308,71 @@ e_tree_init (GtkObject *object)
 
 	GTK_WIDGET_SET_FLAGS (e_tree, GTK_CAN_FOCUS);
 
-	gtk_table->homogeneous               = FALSE;
+	gtk_table->homogeneous                           = FALSE;
 
-	e_tree->priv                         = g_new(ETreePriv, 1);
+	e_tree->priv                                     = g_new(ETreePriv, 1);
 
-	e_tree->priv->model                  = NULL;
-	e_tree->priv->sorted                 = NULL;
-	e_tree->priv->etta                   = NULL;
+	e_tree->priv->model                              = NULL;
+	e_tree->priv->sorted                             = NULL;
+	e_tree->priv->etta                               = NULL;
 
-	e_tree->priv->full_header            = NULL;
-	e_tree->priv->header                 = NULL;
+	e_tree->priv->full_header                        = NULL;
+	e_tree->priv->header                             = NULL;
 
-	e_tree->priv->structure_change_id    = 0;
-	e_tree->priv->expansion_change_id    = 0;
-	e_tree->priv->sort_info_change_id    = 0;
-	e_tree->priv->group_info_change_id   = 0;
+	e_tree->priv->sort_info                          = NULL;
+	e_tree->priv->sorter                             = NULL;
+	e_tree->priv->reflow_idle_id                     = 0;
+	e_tree->priv->scroll_idle_id                     = 0;
+	e_tree->priv->hover_idle_id                     = 0;
 
-	e_tree->priv->sort_info              = NULL;
-	e_tree->priv->sorter                 = NULL;
-	e_tree->priv->reflow_idle_id         = 0;
-	e_tree->priv->scroll_idle_id         = 0;
-	e_tree->priv->hover_idle_id          = 0;
+	e_tree->priv->alternating_row_colors             = 1;
+	e_tree->priv->horizontal_draw_grid               = 1;
+	e_tree->priv->vertical_draw_grid                 = 1;
+	e_tree->priv->draw_focus                         = 1;
+	e_tree->priv->cursor_mode                        = E_CURSOR_SIMPLE;
+	e_tree->priv->length_threshold                   = 200;
+	e_tree->priv->uniform_row_height                 = FALSE;
 
-	e_tree->priv->alternating_row_colors = 1;
-	e_tree->priv->horizontal_draw_grid   = 1;
-	e_tree->priv->vertical_draw_grid     = 1;
-	e_tree->priv->draw_focus             = 1;
-	e_tree->priv->cursor_mode            = E_CURSOR_SIMPLE;
-	e_tree->priv->length_threshold       = 200;
-	e_tree->priv->uniform_row_height     = FALSE;
+	e_tree->priv->row_selection_active               = FALSE;
+	e_tree->priv->horizontal_scrolling               = FALSE;
 
-	e_tree->priv->row_selection_active   = FALSE;
-	e_tree->priv->horizontal_scrolling   = FALSE;
+	e_tree->priv->drop_row                           = -1;
+	e_tree->priv->drop_path                          = NULL;
+	e_tree->priv->drop_col                           = -1;
+	e_tree->priv->drop_highlight                     = NULL;
 
-	e_tree->priv->drop_row               = -1;
-	e_tree->priv->drop_path              = NULL;
-	e_tree->priv->drop_col               = -1;
-	e_tree->priv->drop_highlight         = NULL;
+	e_tree->priv->last_drop_x                        = 0;
+	e_tree->priv->last_drop_y                        = 0;
+	e_tree->priv->last_drop_time                     = 0;
+	e_tree->priv->last_drop_context                  = NULL;
 
-	e_tree->priv->last_drop_x            = 0;
-	e_tree->priv->last_drop_y            = 0;
-	e_tree->priv->last_drop_time         = 0;
-	e_tree->priv->last_drop_context      = NULL;
+	e_tree->priv->hover_x                            = 0;
+	e_tree->priv->hover_y                            = 0;
 
-	e_tree->priv->hover_x                = 0;
-	e_tree->priv->hover_y                = 0;
+	e_tree->priv->drag_row                           = -1;
+	e_tree->priv->drag_path                          = NULL;
+	e_tree->priv->drag_col                           = -1;
 
-	e_tree->priv->drag_row               = -1;
-	e_tree->priv->drag_path              = NULL;
-	e_tree->priv->drag_col               = -1;
+	e_tree->priv->expanded_list                      = NULL;
 
-	e_tree->priv->expanded_list          = NULL;
-
-	e_tree->priv->site                   = NULL;
-	e_tree->priv->do_drag                = FALSE;
+	e_tree->priv->site                               = NULL;
+	e_tree->priv->do_drag                            = FALSE;
 
 #ifdef E_TREE_USE_TREE_SELECTION
-	e_tree->priv->selection              = E_SELECTION_MODEL(e_tree_selection_model_new());
+	e_tree->priv->selection                          = E_SELECTION_MODEL(e_tree_selection_model_new());
 #else
-	e_tree->priv->selection              = E_SELECTION_MODEL(e_table_selection_model_new());
+	e_tree->priv->selection                          = E_SELECTION_MODEL(e_table_selection_model_new());
 #endif
-	e_tree->priv->spec                   = NULL;
+	e_tree->priv->spec                               = NULL;
 
-	e_tree->priv->header_canvas          = NULL;
-	e_tree->priv->table_canvas           = NULL;
+	e_tree->priv->header_canvas                      = NULL;
+	e_tree->priv->table_canvas                       = NULL;
 
-	e_tree->priv->header_item            = NULL;
-	e_tree->priv->root                   = NULL;
+	e_tree->priv->header_item                        = NULL;
+	e_tree->priv->root                               = NULL;
 
-	e_tree->priv->white_item             = NULL;
-	e_tree->priv->item                   = NULL;
-
-	e_tree->priv->search                 = e_table_search_new();
-
-	e_tree->priv->search_search_id       = 
-		gtk_signal_connect (GTK_OBJECT (e_tree->priv->search), "search",
-				    GTK_SIGNAL_FUNC (et_search_search), e_tree);
-	e_tree->priv->search_accept_id       = 
-		gtk_signal_connect (GTK_OBJECT (e_tree->priv->search), "accept",
-				    GTK_SIGNAL_FUNC (et_search_accept), e_tree);
-
-	e_tree->priv->current_search_col     = NULL;
-	e_tree->priv->search_col_set         = FALSE;
-	e_tree->priv->always_search          = g_getenv ("GAL_ALWAYS_SEARCH") ? TRUE : FALSE;
+	e_tree->priv->white_item                         = NULL;
+	e_tree->priv->item                               = NULL;
 }
 
 /* Grab_focus handler for the ETree */
@@ -626,18 +388,18 @@ et_grab_focus (GtkWidget *widget)
 
 /* Focus handler for the ETree */
 static gint
-et_focus (GtkContainer *container, GtkDirectionType direction)
+et_focus (GtkWidget *container, GtkDirectionType direction)
 {
 	ETree *e_tree;
 
 	e_tree = E_TREE (container);
 
-	if (container->focus_child) {
-		gtk_container_set_focus_child (container, NULL);
+	if (GTK_CONTAINER (container)->focus_child) {
+		gtk_container_set_focus_child (GTK_CONTAINER (container), NULL);
 		return FALSE;
 	}
 
-	return gtk_container_focus (GTK_CONTAINER (e_tree->priv->table_canvas), direction);
+	return gtk_widget_child_focus (GTK_WIDGET (e_tree->priv->table_canvas), direction);
 }
 
 static void
@@ -733,6 +495,11 @@ tree_canvas_reflow_idle (ETree *e_tree)
 						0, 0, width - 1, height - 1);
 		set_header_canvas_width (e_tree);
 	}
+	gtk_object_set (GTK_OBJECT (e_tree->priv->white_item),
+			"y1", item_height,
+			"x2", width,
+			"y2", height,
+			NULL);
 	e_tree->priv->reflow_idle_id = 0;
 	return FALSE;
 }
@@ -785,7 +552,7 @@ item_cursor_activated (ETableItem *eti, int row, ETree *et)
 {
 	ETreePath path = e_tree_table_adapter_node_at_row(et->priv->etta, row);
 	if (path)
-		path = e_tree_sorted_view_to_model_path(et->priv->sorted, path);
+	path = e_tree_sorted_view_to_model_path(et->priv->sorted, path);
 	gtk_signal_emit (GTK_OBJECT (et),
 			 et_signals [CURSOR_ACTIVATED],
 			 row, path);
@@ -871,9 +638,6 @@ item_key_press (ETableItem *eti, int row, int col, GdkEvent *event, ETree *et)
 	case '=':
 	case GDK_Right:
 	case GDK_KP_Right:
-		/* Only allow if the Shift modifier is used -- eg. Ctrl-Equal shouldn't be handled.  */
-		if (key->state & ~(GDK_SHIFT_MASK | GDK_LOCK_MASK))
-			break;
 		if (row != -1) {
 			path = e_tree_table_adapter_node_at_row(et->priv->etta, row);
 			if (path)
@@ -884,9 +648,6 @@ item_key_press (ETableItem *eti, int row, int col, GdkEvent *event, ETree *et)
 	case '-':
 	case GDK_Left:
 	case GDK_KP_Left:
-		/* Only allow if the Shift modifier is used -- eg. Ctrl-Minus shouldn't be handled.  */
-		if (key->state & ~(GDK_SHIFT_MASK | GDK_LOCK_MASK))
-			break;
 		if (row != -1) {
 			path = e_tree_table_adapter_node_at_row(et->priv->etta, row);
 			if (path)
@@ -894,17 +655,7 @@ item_key_press (ETableItem *eti, int row, int col, GdkEvent *event, ETree *et)
 		}
 		return_val = 1;
 		break;
-	case GDK_BackSpace:
-		if (e_table_search_backspace (et->priv->search))
-			return TRUE;
-		/* Fallthrough */
 	default:
-		if ((key->state & ~(GDK_SHIFT_MASK | GDK_LOCK_MASK)) == 0
-		    && ((key->keyval >= GDK_a && key->keyval <= GDK_z) ||
-			(key->keyval >= GDK_A && key->keyval <= GDK_Z) ||
-			(key->keyval >= GDK_0 && key->keyval <= GDK_9))) {
-			e_table_search_input_character (et->priv->search, key->keyval);
-		}
 		path = e_tree_table_adapter_node_at_row(et->priv->etta, row);
 		path = e_tree_sorted_view_to_model_path(et->priv->sorted, path);
 		gtk_signal_emit (GTK_OBJECT (et),
@@ -987,16 +738,6 @@ et_canvas_realize (GtkWidget *canvas, ETree *e_tree)
 		NULL);
 }
 
-static gint
-white_item_event (GnomeCanvasItem *white_item, GdkEvent *event, ETree *e_tree)
-{
-	int return_val = 0;
-	gtk_signal_emit (GTK_OBJECT (e_tree),
-			 et_signals [WHITE_SPACE_EVENT],
-			 event, &return_val);
-	return return_val;
-}
-
 static gint
 et_canvas_root_event (GnomeCanvasItem *root, GdkEvent *event, ETree *e_tree)
 {
@@ -1008,12 +749,12 @@ et_canvas_root_event (GnomeCanvasItem *root, GdkEvent *event, ETree *e_tree)
 			if (GTK_WIDGET_HAS_FOCUS(root->canvas)) {
 				GnomeCanvasItem *item = GNOME_CANVAS(root->canvas)->focused_item;
 
-				if (E_IS_TABLE_ITEM(item)) {
+		if (E_IS_TABLE_ITEM(item)) {
 					e_table_item_leave_edit_(E_TABLE_ITEM(item));
 					return TRUE;
 				}
-			}
 		}
+	}
 		break;
 	default:
 		break;
@@ -1093,12 +834,14 @@ e_tree_setup_table (ETree *e_tree)
 
 	e_tree->priv->white_item = gnome_canvas_item_new(
 		gnome_canvas_root(e_tree->priv->table_canvas),
-		e_canvas_background_get_type(),
+		gnome_canvas_rect_get_type(),
+		"x1", (double) 0,
+		"y1", (double) 0,
+		"x2", (double) 100,
+		"y2", (double) 100,
 		"fill_color_gdk", &GTK_WIDGET(e_tree->priv->table_canvas)->style->base[GTK_STATE_NORMAL],
 		NULL);
 
-	gtk_signal_connect (GTK_OBJECT (e_tree->priv->white_item), "event",
-			    GTK_SIGNAL_FUNC (white_item_event), e_tree);
 	gtk_signal_connect (
 		GTK_OBJECT(e_tree->priv->table_canvas), "realize",
 		GTK_SIGNAL_FUNC(et_canvas_realize), e_tree);
@@ -1109,36 +852,26 @@ e_tree_setup_table (ETree *e_tree)
 	et_build_item(e_tree);
 }
 
-/**
- * e_tree_set_search_column:
- * @e_tree: #ETree object that will be modified
- * @col: Column index to use for searches 
- *
- * This routine sets the current search column to be used for keypress
- * searches of the #ETree. If -1 is passed in for column, the current
- * search column is cleared.
- */
-void
-e_tree_set_search_column (ETree *e_tree, gint  col)
-{
-	if (col == -1) {
-		clear_current_search_col (e_tree);
-		return;
-	}
-
-	e_tree->priv->search_col_set = TRUE;
-	e_tree->priv->current_search_col = e_table_header_get_column (e_tree->priv->full_header, col);
-}
-
 void
 e_tree_set_state_object(ETree *e_tree, ETableState *state)
 {
-	connect_header (e_tree, state);
+	if (e_tree->priv->header)
+		gtk_object_unref(GTK_OBJECT(e_tree->priv->header));
+	e_tree->priv->header = e_table_state_to_header (GTK_WIDGET(e_tree), e_tree->priv->full_header, state);
 
 	gtk_object_set (GTK_OBJECT (e_tree->priv->header),
 			"width", (double) (GTK_WIDGET(e_tree->priv->table_canvas)->allocation.width),
 			NULL);
 
+	if (e_tree->priv->sort_info)
+		gtk_object_unref(GTK_OBJECT(e_tree->priv->sort_info));
+
+	if (state->sort_info) {
+		e_tree->priv->sort_info = e_table_sort_info_duplicate(state->sort_info);
+		e_table_sort_info_set_can_group (e_tree->priv->sort_info, FALSE);
+	} else
+		e_tree->priv->sort_info = NULL;
+
 	if (e_tree->priv->header_item)
 		gtk_object_set(GTK_OBJECT(e_tree->priv->header_item),
 			       "ETableHeader", e_tree->priv->header,
@@ -1154,8 +887,6 @@ e_tree_set_state_object(ETree *e_tree, ETableState *state)
 		gtk_object_set(GTK_OBJECT(e_tree->priv->sorted),
 			       "sort_info", e_tree->priv->sort_info,
 			       NULL);
-
-	e_tree_state_change (e_tree);
 }
 
 /**
@@ -1377,9 +1108,18 @@ et_real_construct (ETree *e_tree, ETreeModel *etm, ETableExtras *ete,
 	e_tree->priv->cursor_mode = specification->cursor_mode;
 	e_tree->priv->full_header = e_table_spec_to_full_header(specification, ete);
 
-	connect_header (e_tree, state);
+	e_tree->priv->header = e_table_state_to_header (GTK_WIDGET(e_tree), e_tree->priv->full_header, state);
 	e_tree->priv->horizontal_scrolling = specification->horizontal_scrolling;
 
+	e_tree->priv->sort_info = state->sort_info;
+	gtk_object_ref (GTK_OBJECT (e_tree->priv->sort_info));
+
+	e_table_sort_info_set_can_group (e_tree->priv->sort_info, FALSE);
+
+	gtk_object_set(GTK_OBJECT(e_tree->priv->header),
+		       "sort_info", e_tree->priv->sort_info,
+		       NULL);
+
 	e_tree->priv->model = etm;
 	gtk_object_ref (GTK_OBJECT (etm));
 
@@ -1389,7 +1129,6 @@ et_real_construct (ETree *e_tree, ETreeModel *etm, ETableExtras *ete,
 
 	et_connect_to_etta (e_tree);
 
-	gtk_widget_push_visual (gdk_rgb_get_visual ());
 	gtk_widget_push_colormap (gdk_rgb_get_cmap ());
 
 	e_tree->priv->sorter = e_sorter_new();
@@ -1439,7 +1178,6 @@ et_real_construct (ETree *e_tree, ETreeModel *etm, ETableExtras *ete,
 			  0, 0);
 
 	gtk_widget_pop_colormap ();
-	gtk_widget_pop_visual ();
 
 	gtk_object_unref(GTK_OBJECT(ete));
 
@@ -1656,8 +1394,6 @@ e_tree_set_cursor (ETree *e_tree, ETreePath path)
 #else
 	path = e_tree_sorted_model_to_view_path(e_tree->priv->sorted, path);
 
-	g_return_if_fail(path != NULL);
-
 	row = e_tree_table_adapter_row_of_node(E_TREE_TABLE_ADAPTER(e_tree->priv->etta), path);
 
 	if (row == -1)
@@ -1717,42 +1453,6 @@ e_tree_selected_path_foreach     (ETree *e_tree,
 				       callback,
 				       closure);
 }
-
-/* Standard functions */
-static void
-et_foreach_recurse (ETreeModel *model,
-		    ETreePath path,
-		    ETreeForeachFunc callback,
-		    gpointer closure)
-{
-	ETreePath child;
-
-	callback(path, closure);
-
-	child = e_tree_model_node_get_first_child(E_TREE_MODEL(model), path);
-	for ( ; child; child = e_tree_model_node_get_next(E_TREE_MODEL(model), child))
-		if (child)
-			et_foreach_recurse (model, child, callback, closure);
-}
-
-void
-e_tree_path_foreach (ETree *e_tree,
-		     ETreeForeachFunc callback,
-		     gpointer closure)
-{
-	ETreePath root;
-
-	g_return_if_fail(e_tree != NULL);
-	g_return_if_fail(E_IS_TREE(e_tree));
-
-	root = e_tree_model_get_root (e_tree->priv->model);
-
-	if (root)
-		et_foreach_recurse (e_tree->priv->model,
-				    root,
-				    callback,
-				    closure);
-}
 #endif
 
 EPrintable *
@@ -1778,9 +1478,6 @@ et_get_arg (GtkObject *o, GtkArg *arg, guint arg_id)
 	case ARG_UNIFORM_ROW_HEIGHT:
 		GTK_VALUE_BOOL (*arg) = etree->priv->uniform_row_height;
 		break;
-	case ARG_ALWAYS_SEARCH:
-		GTK_VALUE_BOOL (*arg) = etree->priv->always_search;
-		break;
 
 	default:
 		break;
@@ -1842,13 +1539,6 @@ et_set_arg (GtkObject *o, GtkArg *arg, guint arg_id)
 					       NULL);
 		}
 		break;
-
-	case ARG_ALWAYS_SEARCH:
-		if (etree->priv->always_search == GTK_VALUE_BOOL (*arg))
-			return;
-		etree->priv->always_search = GTK_VALUE_BOOL (*arg);
-		clear_current_search_col (etree);
-		break;
 	}
 }
 
@@ -1949,7 +1639,7 @@ e_tree_node_is_expanded (ETree *et, ETreePath path)
 {
 	path = e_tree_sorted_model_to_view_path(et->priv->sorted, path);
 
-	g_return_val_if_fail(path != NULL, FALSE);
+	g_return_val_if_fail(path, FALSE);
 
 	return e_tree_table_adapter_node_is_expanded (et->priv->etta, path);
 }
@@ -1962,8 +1652,6 @@ e_tree_node_set_expanded (ETree *et, ETreePath path, gboolean expanded)
 
 	path = e_tree_sorted_model_to_view_path(et->priv->sorted, path);
 
-	g_return_if_fail(path != NULL);
-
 	e_tree_table_adapter_node_set_expanded (et->priv->etta, path, expanded);
 }
 
@@ -1975,8 +1663,6 @@ e_tree_node_set_expanded_recurse (ETree *et, ETreePath path, gboolean expanded)
 
 	path = e_tree_sorted_model_to_view_path(et->priv->sorted, path);
 
-	g_return_if_fail(path != NULL);
-
 	e_tree_table_adapter_node_set_expanded_recurse (et->priv->etta, path, expanded);
 }
 
@@ -2004,9 +1690,6 @@ int
 e_tree_row_of_node (ETree *et, ETreePath path)
 {
 	path = e_tree_sorted_model_to_view_path(et->priv->sorted, path);
-
-	g_return_val_if_fail(path != NULL, 0);
-
 	return e_tree_table_adapter_row_of_node (et->priv->etta, path);
 }
 
@@ -2024,8 +1707,6 @@ e_tree_show_node (ETree *et, ETreePath path)
 
 	path = e_tree_sorted_model_to_view_path(et->priv->sorted, path);
 
-	g_return_if_fail(path != NULL);
-
 	e_tree_table_adapter_show_node (et->priv->etta, path);
 }
 
@@ -2087,8 +1768,6 @@ e_tree_find_next (ETree *et, ETreeFindNextParams params, ETreePathFunc func, gpo
 	cursor = e_tree_get_cursor (et);
 	cursor = e_tree_sorted_model_to_view_path (et->priv->sorted, cursor);
 
-	g_return_val_if_fail(cursor != NULL, FALSE);
-
 	found = e_tree_model_node_find (E_TREE_MODEL (et->priv->sorted), cursor, NULL, params & E_TREE_FIND_NEXT_FORWARD, find_next_callback, &cb_data);
 
 	if (found) {
@@ -2152,23 +1831,6 @@ e_tree_get_selection_model (ETree *et)
 	return et->priv->selection;
 }
 
-/**
- * e_tree_get_table_adapter:
- * @et: the ETree
- *
- * Returns the table adapter this ETree uses.
- *
- * Returns: the model
- **/
-ETreeTableAdapter *
-e_tree_get_table_adapter (ETree *et)
-{
-	g_return_val_if_fail (et != NULL, NULL);
-	g_return_val_if_fail (E_IS_TREE (et), NULL);
-
-	return et->priv->etta;
-}
-
 
 struct _ETreeDragSourceSite
 {
@@ -2480,8 +2142,6 @@ e_tree_drag_source_unset (ETree *tree)
 	site = tree->priv->site;
 
 	if (site) {
-		if (site->target_list)
-			gtk_target_list_unref (site->target_list);
 		g_free (site);
 		tree->priv->site = NULL;
 	}
@@ -2753,7 +2413,7 @@ scroll_off (ETree *et)
 		et->priv->scroll_idle_id = 0;
 	}
 }
-
+ 
 static gboolean
 hover_timeout (gpointer data)
 {
@@ -2777,8 +2437,8 @@ hover_timeout (gpointer data)
 		if (!e_tree_table_adapter_node_is_expanded (et->priv->etta, path)) {
 			if (e_tree_model_has_save_id (E_TREE_MODEL (et->priv->sorted)) && e_tree_model_has_get_node_by_id (E_TREE_MODEL (et->priv->sorted)))
 				et->priv->expanded_list = g_list_prepend (et->priv->expanded_list, e_tree_model_get_save_id (E_TREE_MODEL (et->priv->sorted), path));
-			e_tree_table_adapter_node_set_expanded (et->priv->etta, path, TRUE);
-		}
+		e_tree_table_adapter_node_set_expanded (et->priv->etta, path, TRUE);
+	}
 	}
 
 	return TRUE;
@@ -2918,7 +2578,7 @@ et_drag_motion(GtkWidget *widget,
 	x -= widget->allocation.x;
 	y -= widget->allocation.y;
 
-	if (y < 20)
+		if (y < 20)
 		direction |= ET_SCROLL_UP;
 	if (y > widget->allocation.height - 20)
 		direction |= ET_SCROLL_DOWN;
@@ -2929,7 +2589,7 @@ et_drag_motion(GtkWidget *widget,
 
 	if (direction != 0)
 		scroll_on (et, direction);
-	else
+		else
 		scroll_off (et);
 
 	return ret_val;
@@ -3053,9 +2713,8 @@ e_tree_class_init (ETreeClass *class)
 	object_class->get_arg          = et_get_arg;
 
 	widget_class->grab_focus       = et_grab_focus;
-	widget_class->unrealize        = et_unrealize;
 
-	container_class->focus         = et_focus;
+	widget_class->focus            = et_focus;
 
 	class->cursor_change           = NULL;
 	class->cursor_activated        = NULL;
@@ -3065,8 +2724,6 @@ e_tree_class_init (ETreeClass *class)
 	class->click                   = NULL;
 	class->key_press               = NULL;
 	class->start_drag              = et_real_start_drag;
-	class->state_change            = NULL;
-	class->white_space_event       = NULL;
 
 	class->tree_drag_begin         = NULL;
 	class->tree_drag_end           = NULL;
@@ -3083,7 +2740,7 @@ e_tree_class_init (ETreeClass *class)
 				GTK_RUN_LAST,
 				E_OBJECT_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (ETreeClass, cursor_change),
-				gtk_marshal_NONE__INT_POINTER,
+				e_marshal_NONE__INT_POINTER,
 				GTK_TYPE_NONE, 2, GTK_TYPE_INT, GTK_TYPE_POINTER);
 
 	et_signals [CURSOR_ACTIVATED] =
@@ -3091,7 +2748,7 @@ e_tree_class_init (ETreeClass *class)
 				GTK_RUN_LAST,
 				E_OBJECT_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (ETreeClass, cursor_activated),
-				gtk_marshal_NONE__INT_POINTER,
+				e_marshal_NONE__INT_POINTER,
 				GTK_TYPE_NONE, 2, GTK_TYPE_INT, GTK_TYPE_POINTER);
 
 	et_signals [SELECTION_CHANGE] =
@@ -3107,90 +2764,79 @@ e_tree_class_init (ETreeClass *class)
 				GTK_RUN_LAST,
 				E_OBJECT_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (ETreeClass, double_click),
-				e_marshal_NONE__INT_POINTER_INT_POINTER,
-				GTK_TYPE_NONE, 4, GTK_TYPE_INT, GTK_TYPE_POINTER, GTK_TYPE_INT, GTK_TYPE_GDK_EVENT);
+				e_marshal_NONE__INT_POINTER_INT_BOXED,
+				GTK_TYPE_NONE, 4, GTK_TYPE_INT,
+				GTK_TYPE_POINTER, GTK_TYPE_INT, GDK_TYPE_EVENT);
 
 	et_signals [RIGHT_CLICK] =
 		gtk_signal_new ("right_click",
 				GTK_RUN_LAST,
 				E_OBJECT_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (ETreeClass, right_click),
-				e_marshal_INT__INT_POINTER_INT_POINTER,
-				GTK_TYPE_INT, 4, GTK_TYPE_INT, GTK_TYPE_POINTER, GTK_TYPE_INT, GTK_TYPE_GDK_EVENT);
+				e_marshal_INT__INT_POINTER_INT_BOXED,
+				GTK_TYPE_INT, 4, GTK_TYPE_INT, GTK_TYPE_POINTER,
+				GTK_TYPE_INT, GDK_TYPE_EVENT);
 
 	et_signals [CLICK] =
 		gtk_signal_new ("click",
 				GTK_RUN_LAST,
 				E_OBJECT_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (ETreeClass, click),
-				e_marshal_INT__INT_POINTER_INT_POINTER,
-				GTK_TYPE_INT, 4, GTK_TYPE_INT, GTK_TYPE_POINTER, GTK_TYPE_INT, GTK_TYPE_GDK_EVENT);
+				e_marshal_INT__INT_POINTER_INT_BOXED,
+				GTK_TYPE_INT, 4, GTK_TYPE_INT, GTK_TYPE_POINTER,
+				GTK_TYPE_INT, GDK_TYPE_EVENT);
 
 	et_signals [KEY_PRESS] =
 		gtk_signal_new ("key_press",
 				GTK_RUN_LAST,
 				E_OBJECT_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (ETreeClass, key_press),
-				e_marshal_INT__INT_POINTER_INT_POINTER,
-				GTK_TYPE_INT, 4, GTK_TYPE_INT, GTK_TYPE_POINTER, GTK_TYPE_INT, GTK_TYPE_GDK_EVENT);
+				e_marshal_INT__INT_POINTER_INT_BOXED,
+				GTK_TYPE_INT, 4, GTK_TYPE_INT, GTK_TYPE_POINTER,
+				GTK_TYPE_INT, GDK_TYPE_EVENT);
 
 	et_signals [START_DRAG] =
 		gtk_signal_new ("start_drag",
 				GTK_RUN_LAST,
 				E_OBJECT_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (ETreeClass, start_drag),
-				e_marshal_NONE__INT_POINTER_INT_POINTER,
-				GTK_TYPE_NONE, 4, GTK_TYPE_INT, GTK_TYPE_POINTER, GTK_TYPE_INT, GTK_TYPE_GDK_EVENT);
-
-	et_signals [STATE_CHANGE] =
-		gtk_signal_new ("state_change",
-				GTK_RUN_LAST,
-				E_OBJECT_CLASS_TYPE (object_class),
-				GTK_SIGNAL_OFFSET (ETreeClass, state_change),
-				gtk_marshal_NONE__NONE,
-				GTK_TYPE_NONE, 0);
-
-	et_signals [WHITE_SPACE_EVENT] =
-		gtk_signal_new ("white_space_event",
-				GTK_RUN_LAST,
-				E_OBJECT_CLASS_TYPE (object_class),
-				GTK_SIGNAL_OFFSET (ETreeClass, white_space_event),
-				gtk_marshal_INT__POINTER,
-				GTK_TYPE_INT, 1, GTK_TYPE_GDK_EVENT);
+				e_marshal_NONE__INT_POINTER_INT_BOXED,
+				GTK_TYPE_NONE, 4, GTK_TYPE_INT, GTK_TYPE_POINTER,
+				GTK_TYPE_INT, GDK_TYPE_EVENT);
 
 	et_signals[TREE_DRAG_BEGIN] =
 		gtk_signal_new ("tree_drag_begin",
 				GTK_RUN_LAST,
 				E_OBJECT_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (ETreeClass, tree_drag_begin),
-				e_marshal_NONE__INT_POINTER_INT_POINTER,
+				e_marshal_NONE__INT_POINTER_INT_BOXED,
 				GTK_TYPE_NONE, 4,
 				GTK_TYPE_INT,
 				GTK_TYPE_POINTER,
 				GTK_TYPE_INT,
-				GTK_TYPE_GDK_DRAG_CONTEXT);
+				GDK_TYPE_DRAG_CONTEXT);
 	et_signals[TREE_DRAG_END] =
 		gtk_signal_new ("tree_drag_end",
 				GTK_RUN_LAST,
 				E_OBJECT_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (ETreeClass, tree_drag_end),
-				e_marshal_NONE__INT_POINTER_INT_POINTER,
+				e_marshal_NONE__INT_POINTER_INT_BOXED,
 				GTK_TYPE_NONE, 4,
 				GTK_TYPE_INT,
 				GTK_TYPE_POINTER,
 				GTK_TYPE_INT,
-				GTK_TYPE_GDK_DRAG_CONTEXT);
+				GDK_TYPE_DRAG_CONTEXT);
 	et_signals[TREE_DRAG_DATA_GET] =
 		gtk_signal_new ("tree_drag_data_get",
 				GTK_RUN_LAST,
 				E_OBJECT_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (ETreeClass, tree_drag_data_get),
-				e_marshal_NONE__INT_POINTER_INT_POINTER_POINTER_UINT_UINT,
+				e_marshal_NONE__INT_POINTER_INT_OBJECT_BOXED_UINT_UINT,
 				GTK_TYPE_NONE, 7,
 				GTK_TYPE_INT,
 				GTK_TYPE_POINTER,
 				GTK_TYPE_INT,
-				GTK_TYPE_GDK_DRAG_CONTEXT,
+				GDK_TYPE_DRAG_CONTEXT,
 				GTK_TYPE_SELECTION_DATA,
 				GTK_TYPE_UINT,
 				GTK_TYPE_UINT);
@@ -3199,36 +2845,36 @@ e_tree_class_init (ETreeClass *class)
 				GTK_RUN_LAST,
 				E_OBJECT_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (ETreeClass, tree_drag_data_delete),
-				e_marshal_NONE__INT_POINTER_INT_POINTER,
+				e_marshal_NONE__INT_POINTER_INT_OBJECT,
 				GTK_TYPE_NONE, 4,
 				GTK_TYPE_INT,
 				GTK_TYPE_POINTER,
 				GTK_TYPE_INT,
-				GTK_TYPE_GDK_DRAG_CONTEXT);
+				GDK_TYPE_DRAG_CONTEXT);
 
 	et_signals[TREE_DRAG_LEAVE] =
 		gtk_signal_new ("tree_drag_leave",
 				GTK_RUN_LAST,
 				E_OBJECT_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (ETreeClass, tree_drag_leave),
-				e_marshal_NONE__INT_POINTER_INT_POINTER_UINT,
+				e_marshal_NONE__INT_POINTER_INT_OBJECT_UINT,
 				GTK_TYPE_NONE, 5,
 				GTK_TYPE_INT,
 				GTK_TYPE_POINTER,
 				GTK_TYPE_INT,
-				GTK_TYPE_GDK_DRAG_CONTEXT,
+				GDK_TYPE_DRAG_CONTEXT,
 				GTK_TYPE_UINT);
 	et_signals[TREE_DRAG_MOTION] =
 		gtk_signal_new ("tree_drag_motion",
 				GTK_RUN_LAST,
 				E_OBJECT_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (ETreeClass, tree_drag_motion),
-				e_marshal_BOOL__INT_POINTER_INT_POINTER_INT_INT_UINT,
+				e_marshal_BOOLEAN__INT_POINTER_INT_OBJECT_INT_INT_UINT,
 				GTK_TYPE_BOOL, 7,
 				GTK_TYPE_INT,
 				GTK_TYPE_POINTER,
 				GTK_TYPE_INT,
-				GTK_TYPE_GDK_DRAG_CONTEXT,
+				GDK_TYPE_DRAG_CONTEXT,
 				GTK_TYPE_INT,
 				GTK_TYPE_INT,
 				GTK_TYPE_UINT);
@@ -3237,12 +2883,12 @@ e_tree_class_init (ETreeClass *class)
 				GTK_RUN_LAST,
 				E_OBJECT_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (ETreeClass, tree_drag_drop),
-				e_marshal_BOOL__INT_POINTER_INT_POINTER_INT_INT_UINT,
+				e_marshal_BOOLEAN__INT_POINTER_INT_OBJECT_INT_INT_UINT,
 				GTK_TYPE_BOOL, 7,
 				GTK_TYPE_INT,
 				GTK_TYPE_POINTER,
 				GTK_TYPE_INT,
-				GTK_TYPE_GDK_DRAG_CONTEXT,
+				GDK_TYPE_DRAG_CONTEXT,
 				GTK_TYPE_INT,
 				GTK_TYPE_INT,
 				GTK_TYPE_UINT);
@@ -3251,12 +2897,12 @@ e_tree_class_init (ETreeClass *class)
 				GTK_RUN_LAST,
 				E_OBJECT_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (ETreeClass, tree_drag_data_received),
-				e_marshal_NONE__INT_POINTER_INT_POINTER_INT_INT_POINTER_UINT_UINT,
+				e_marshal_NONE__INT_POINTER_INT_OBJECT_INT_INT_BOXED_UINT_UINT,
 				GTK_TYPE_NONE, 9,
 				GTK_TYPE_INT,
 				GTK_TYPE_POINTER,
 				GTK_TYPE_INT,
-				GTK_TYPE_GDK_DRAG_CONTEXT,
+				GDK_TYPE_DRAG_CONTEXT,
 				GTK_TYPE_INT,
 				GTK_TYPE_INT,
 				GTK_TYPE_SELECTION_DATA,
@@ -3272,8 +2918,9 @@ e_tree_class_init (ETreeClass *class)
 				GTK_RUN_LAST,
 				E_OBJECT_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (ETreeClass, set_scroll_adjustments),
-				gtk_marshal_NONE__POINTER_POINTER,
-				GTK_TYPE_NONE, 2, GTK_TYPE_ADJUSTMENT, GTK_TYPE_ADJUSTMENT);
+				e_marshal_NONE__POINTER_POINTER,
+				GTK_TYPE_NONE, 2, GTK_TYPE_ADJUSTMENT,
+				GTK_TYPE_ADJUSTMENT);
 
 	gtk_object_add_arg_type ("ETree::length_threshold", GTK_TYPE_INT,
 				 GTK_ARG_WRITABLE, ARG_LENGTH_THRESHOLD);
@@ -3287,8 +2934,6 @@ e_tree_class_init (ETreeClass *class)
 				 GTK_ARG_READABLE, ARG_ETTA);
 	gtk_object_add_arg_type ("ETree::uniform_row_height", GTK_TYPE_BOOL,
 				 GTK_ARG_READWRITE, ARG_UNIFORM_ROW_HEIGHT);
-	gtk_object_add_arg_type ("ETree::always_search", GTK_TYPE_BOOL,
-				 GTK_ARG_READWRITE, ARG_ALWAYS_SEARCH);
 }
 
-E_MAKE_TYPE(e_tree, "ETree", ETree, e_tree_class_init, e_tree_init, PARENT_TYPE)
+E_MAKE_TYPE(e_tree, "ETree", ETree, e_tree_class_init, e_tree_init, PARENT_TYPE);
