@@ -1,10 +1,24 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-
-/* ETextModelURI - A Text Model w/ clickable URIs
- * Copyright (C) 2001 Ximian, Inc.
+/* 
+ * e-text-model-uri.h - a text model w/ clickable URIs
+ * Copyright 2000, 2001, Ximian, Inc.
  *
- * Author: Jon Trowbridge <trow@gnu.org>
+ * Authors:
+ *   Jon Trowbridge <trow@ximian.com>
  *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public
+ * License, version 2, as published by the Free Software Foundation.
+ *
+ * This library is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU Library General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
+ * 02111-1307, USA.
  */
 
 #ifndef E_TEXT_MODEL_URI_H
@@ -12,7 +26,7 @@
 
 #include <gal/e-text/e-text-model.h>
 
-BEGIN_GNOME_DECLS
+G_BEGIN_DECLS
 
 #define E_TYPE_TEXT_MODEL_URI            (e_text_model_get_type ())
 #define E_TEXT_MODEL_URI(obj)            (GTK_CHECK_CAST ((obj), E_TYPE_TEXT_MODEL_URI, ETextModelURI))
@@ -37,6 +51,6 @@ struct _ETextModelURIClass {
 GtkType e_text_model_uri_get_type (void);
 ETextModel *e_text_model_uri_new (void);
 
-END_GNOME_DECLS
+G_END_DECLS
 
 #endif
