@@ -44,7 +44,7 @@
 #define COLOR_PREVIEW_HEIGHT 15
 
 enum {
-	CHANGED,
+	COLOR_CHANGED,
 	LAST_SIGNAL
 };
 
@@ -86,17 +86,15 @@ color_palette_class_init (GObjectClass *object_class)
 
 	color_palette_parent_class = g_type_class_peek_parent (object_class);
 
-	color_palette_signals [CHANGED] =
+	color_palette_signals [COLOR_CHANGED] =
 		gtk_signal_new (
-			"changed",
+			"color_changed",
 			GTK_RUN_LAST,
 			E_OBJECT_CLASS_TYPE (object_class),
-			GTK_SIGNAL_OFFSET (ColorPaletteClass, changed),
-			e_marshal_NONE__POINTER_BOOLEAN_BOOLEAN,
-			GTK_TYPE_NONE, 3, GTK_TYPE_POINTER,
-			GTK_TYPE_BOOL, GTK_TYPE_BOOL);
-
-	E_OBJECT_CLASS_ADD_SIGNALS (object_class, color_palette_signals, LAST_SIGNAL);
+			GTK_SIGNAL_OFFSET (ColorPaletteClass, color_changed),
+			e_marshal_NONE__POINTER_BOOLEAN_BOOLEAN_BOOLEAN,
+			GTK_TYPE_NONE, 4, GTK_TYPE_POINTER,
+			GTK_TYPE_BOOL, GTK_TYPE_BOOL, GTK_TYPE_BOOL);
 }
 
 GtkType
@@ -122,28 +120,25 @@ color_palette_get_type (void)
 	return type;
 }
 
-/*
- * Fires signal "changed" with color as its param
- *
- * prop
- */
 static void
-emit_change (ColorPalette *P, GdkColor *color, gboolean custom, gboolean by_user)
+emit_color_changed (ColorPalette *P, GdkColor *color,
+		    gboolean custom, gboolean by_user, gboolean is_default)
 {
-	GdkColor *new;
-	
-	/* Set it as current color */
+	GdkColor *new = make_color (P, color);
+
+	if (new != NULL)
+		new = gdk_color_copy (new);
 	if (P->current_color)
 		gdk_color_free (P->current_color);
-	new = make_color (P, color);
-	P->current_color = new ? gdk_color_copy (new) : NULL;
+	P->current_color = new;
+	P->current_is_default = is_default;
 
 	/* Only add custom colors to the group */
 	if (custom && color)
 		color_group_add_color (P->color_group, color);
 	
-	gtk_signal_emit (
-		GTK_OBJECT (P), color_palette_signals [CHANGED], color, custom, by_user);
+	gtk_signal_emit (GTK_OBJECT (P), color_palette_signals [COLOR_CHANGED],
+		color, custom, by_user, is_default);
 }
 
 
@@ -213,17 +208,13 @@ cust_color_set (GtkWidget  *color_picker, guint r, guint g, guint b, guint a,
 	c_color.blue  = (gushort)b;
 
 	e_color_alloc_gdk (NULL, &c_color);
-	emit_change (P, &c_color, TRUE, TRUE);
+	emit_color_changed (P, &c_color, TRUE, TRUE, FALSE);
 }
 
-/*
- * NoColour/Auto button was pressed.
- * emit a signal with 'NULL' color.
- */
 static void
-cb_nocolor_clicked (GtkWidget *button, ColorPalette *P)
+cb_default_clicked (GtkWidget *button, ColorPalette *P)
 {
-	emit_change (P, P->default_color, FALSE, TRUE);
+	emit_color_changed (P, P->default_color, FALSE, TRUE, TRUE);
 }
 
 /*
@@ -244,7 +235,7 @@ color_clicked (GtkWidget *button, ColorPalette *P)
 		"fill_color_gdk", &gdk_color,
 		NULL);
 
-	emit_change (P, gdk_color, FALSE, TRUE);
+	emit_color_changed (P, gdk_color, FALSE, TRUE, FALSE);
 
 	gdk_color_free (gdk_color);
 }
@@ -367,7 +358,7 @@ color_palette_setup (ColorPalette *P,
 		     int ncols, int nrows,
 		     ColorNamePair *color_names)
 {
-	GtkWidget *nocolor_button;
+	GtkWidget *default_button;
 	GtkWidget *cust_label;
 	GtkWidget *table;
 	GtkTooltips *tool_tip;
@@ -377,12 +368,12 @@ color_palette_setup (ColorPalette *P,
 
 
 	if (no_color_label != NULL) {
-		nocolor_button = gtk_button_new_with_label (no_color_label);
+		default_button = gtk_button_new_with_label (no_color_label);
 
-		gtk_table_attach (GTK_TABLE (table), nocolor_button,
+		gtk_table_attach (GTK_TABLE (table), default_button,
 				  0, ncols, 0, 1, GTK_FILL | GTK_EXPAND, 0, 0, 0);
-		gtk_signal_connect (GTK_OBJECT (nocolor_button), "clicked",
-				    GTK_SIGNAL_FUNC(cb_nocolor_clicked), P);
+		gtk_signal_connect (GTK_OBJECT (default_button), "clicked",
+				    GTK_SIGNAL_FUNC (cb_default_clicked), P);
 	}
 
 	P->tool_tip = tool_tip = gtk_tooltips_new();
@@ -460,21 +451,38 @@ color_palette_setup (ColorPalette *P,
 	return table;
 }
 
+void
+color_palette_set_color_to_default (ColorPalette *P)
+{
+	g_return_if_fail (P != NULL);
+	g_return_if_fail (IS_COLOR_GROUP (P->color_group));
+
+	emit_color_changed (P, P->default_color, FALSE, TRUE, TRUE);
+}
+
 void
 color_palette_set_current_color (ColorPalette *P, GdkColor *color)
 {
 	g_return_if_fail (P != NULL);
 	g_return_if_fail (IS_COLOR_GROUP (P->color_group));
 
-	emit_change (P, color, color_in_palette (P->default_set, color), FALSE);
+	if (color)
+		emit_color_changed
+			(P, color, color_in_palette (P->default_set, color),
+			 FALSE, FALSE);
+	else
+		color_palette_set_color_to_default (P);
 }
 
 GdkColor *
-color_palette_get_current_color(ColorPalette *P)
+color_palette_get_current_color (ColorPalette *P, gboolean *is_default)
 {
 	g_return_val_if_fail (P != NULL, NULL);
 	g_return_val_if_fail (IS_COLOR_GROUP (P->color_group), NULL);
 
+	if (is_default != NULL)
+		*is_default = P->current_is_default;
+
 	return P->current_color ? gdk_color_copy (P->current_color) : NULL;
 }
 
@@ -532,6 +540,7 @@ color_palette_new_with_vals (char const * const no_color_label,
 	P->default_set   = color_names;
 	P->default_color = default_color;
 	P->current_color = default_color ? gdk_color_copy (default_color) : NULL;
+	P->current_is_default = TRUE;
 	color_palette_set_group (P, cg);
 
 	color_palette_construct (P, no_color_label, ncols, nrows);
